@@ -158,7 +158,6 @@ struct _XfceAppfinderWindow
 
   GdkPixbuf                  *icon_find;
 
-  GtkWidget                  *bbox;
   GtkWidget                  *button_launch;
 
   GarconMenuDirectory        *filter_category;
@@ -213,9 +212,9 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
   GtkTreeViewColumn  *column;
   GtkCellRenderer    *renderer;
   GtkTreeSelection   *selection;
-  GtkWidget          *bbox;
   GtkWidget          *button;
   GtkEntryCompletion *completion;
+  GtkCellRenderer    *cell;
   gint                integer;
 
   window->channel = xfconf_channel_get ("xfce4-appfinder");
@@ -232,7 +231,7 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
   gtk_window_set_title (GTK_WINDOW (window), _("Application Finder"));
   integer = xfconf_channel_get_int (window->channel, "/last/window-width", DEFAULT_WINDOW_WIDTH);
   gtk_window_set_default_size (GTK_WINDOW (window), integer, -1);
-  gtk_window_set_icon_name (GTK_WINDOW (window), XFCE_APPFINDER_STOCK_EXECUTE);
+  gtk_window_set_icon_name (GTK_WINDOW (window), "org.xfce.appfinder");
 
   if (xfconf_channel_get_bool (window->channel, "/always-center", FALSE))
     {
@@ -281,10 +280,16 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
   window->completion = completion = gtk_entry_completion_new ();
   gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (window->model));
   gtk_entry_completion_set_match_func (completion, xfce_appfinder_window_completion_match_func, window, NULL);
-  gtk_entry_completion_set_text_column (completion, XFCE_APPFINDER_MODEL_COLUMN_COMMAND);
+  g_object_set (G_OBJECT (completion), "text-column", XFCE_APPFINDER_MODEL_COLUMN_COMMAND, NULL);
   gtk_entry_completion_set_popup_single_match (completion, TRUE);
   gtk_entry_completion_set_inline_completion (completion, TRUE);
 
+  cell = gtk_cell_renderer_text_new ();
+  g_object_set (G_OBJECT (cell), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+  gtk_cell_renderer_set_fixed_size (cell, 1, -1);
+  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion), cell, TRUE);
+  gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (completion), cell, "text", XFCE_APPFINDER_MODEL_COLUMN_COMMAND);
+
   if (xfconf_channel_get_bool (window->channel, "/disable-completion", FALSE))
     gtk_entry_completion_set_popup_completion (completion, FALSE);
 
@@ -344,7 +349,7 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
   /* set the icon or tree view */
   xfce_appfinder_window_view (window);
 
-  window->bbox = hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show (hbox);
 
@@ -359,25 +364,8 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
   image = gtk_image_new_from_icon_name (XFCE_APPFINDER_STOCK_PREFERENCES, GTK_ICON_SIZE_BUTTON);
   gtk_button_set_image (GTK_BUTTON (button), image);
 
-  bbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
-  gtk_box_set_spacing (GTK_BOX (bbox), 6);
-
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
-  gtk_box_pack_start (GTK_BOX (hbox), bbox, TRUE, TRUE, 0);
-  gtk_widget_show (bbox);
-
-  button = gtk_button_new_with_mnemonic (_("Close"));
-  gtk_container_add (GTK_CONTAINER (bbox), button);
-  g_signal_connect_swapped (G_OBJECT (button), "clicked",
-      G_CALLBACK (gtk_widget_destroy), window);
-  gtk_button_set_always_show_image(GTK_BUTTON(button), TRUE);
-  gtk_widget_show (button);
-
-  image = gtk_image_new_from_icon_name (XFCE_APPFINDER_STOCK_CLOSE, GTK_ICON_SIZE_BUTTON);
-  gtk_button_set_image (GTK_BUTTON (button), image);
-
   window->button_launch = button = gtk_button_new_with_mnemonic (_("La_unch"));
-  gtk_container_add (GTK_CONTAINER (bbox), button);
+  gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
   g_signal_connect_swapped (G_OBJECT (button), "clicked",
       G_CALLBACK (xfce_appfinder_window_launch_clicked), window);
   gtk_widget_set_sensitive (button, FALSE);
